onUnknownTag property
Unknown-tag callback — see fluentSpansToInline. Null asserts in debug on a tag with no builder and no style.
Implementation
final void Function(FluentMarkupSpan node)? onUnknownTag;
Unknown-tag callback — see fluentSpansToInline. Null asserts in debug on a tag with no builder and no style.
final void Function(FluentMarkupSpan node)? onUnknownTag;